@@ -3,9 +3,6 @@
 # 2.0, and the MIT License.  See the LICENSE file in the root of this
 # repository for complete details.
 
-"""
-Structured Logging for Python
-"""
 
 from __future__ import annotations
 
@@ -18,6 +15,7 @@ from structlog import (
     threadlocal,
     tracebacks,
     types,
+    typing,
 )
 from structlog._base import BoundLoggerBase, get_context
 from structlog._config import (
@@ -32,7 +30,7 @@ from structlog._config import (
 )
 from structlog._generic import BoundLogger
 from structlog._log_levels import make_filtering_bound_logger
-from structlog._loggers import (
+from structlog._output import (
     BytesLogger,
     BytesLoggerFactory,
     PrintLogger,
@@ -47,19 +45,12 @@ from structlog.testing import ReturnLogger, ReturnLoggerFactory
 try:
     from structlog import twisted
 except ImportError:
-    twisted = None  # type: ignore
+    twisted = None  # type: ignore[assignment]
 
 
-__version__ = "22.1.0"
-
 __title__ = "structlog"
-# __doc__ is None when running with PYTHONOPTIMIZE=2 / -OO
-__description__ = (__doc__ or "").strip()
-
-__uri__ = "https://www.structlog.org/"
 
 __author__ = "Hynek Schlawack"
-__email__ = "hs@ox.cx"
 
 __license__ = "MIT or Apache License, Version 2.0"
 __copyright__ = "Copyright (c) 2013 " + __author__
@@ -93,7 +84,45 @@ __all__ = [
     "tracebacks",
     "twisted",
     "types",
+    "typing",
     "wrap_logger",
     "WriteLogger",
     "WriteLoggerFactory",
 ]
+
+
+def __getattr__(name: str) -> str:
+    dunder_to_metadata = {
+        "__version__": "version",
+        "__description__": "summary",
+        "__uri__": "",
+        "__email__": "",
+    }
+    if name not in dunder_to_metadata.keys():
+        raise AttributeError(f"module {__name__} has no attribute {name}")
+
+    import sys
+    import warnings
+
+    if sys.version_info < (3, 8):
+        from importlib_metadata import metadata
+    else:
+        from importlib.metadata import metadata
+
+    warnings.warn(
+        f"Accessing structlog.{name} is deprecated and will be "
+        "removed in a future release. Use importlib.metadata directly "
+        "to query for structlog's packaging metadata.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
+    meta = metadata("structlog")
+
+    if name == "__uri__":
+        return meta["Project-URL"].split(" ", 1)[-1]
+
+    if name == "__email__":
+        return meta["Author-email"].split("<", 1)[1].rstrip(">")
+
+    return meta[dunder_to_metadata[name]]
