@@ -18,10 +18,18 @@ from typing import Any, Generator, NamedTuple, NoReturn
 
 from ._config import configure, get_config
 from .exceptions import DropEvent
-from .types import EventDict, WrappedLogger
+from .typing import EventDict, WrappedLogger
 
 
-__all__ = ["LogCapture", "capture_logs"]
+__all__ = [
+    "CapturedCall",
+    "CapturingLogger",
+    "CapturingLoggerFactory",
+    "LogCapture",
+    "ReturnLogger",
+    "ReturnLoggerFactory",
+    "capture_logs",
+]
 
 
 class LogCapture:
@@ -30,7 +38,7 @@ class LogCapture:
     Generally you should use `structlog.testing.capture_logs`,
     but you can use this class if you want to capture logs with other patterns.
 
-    :ivar List[structlog.types.EventDict] entries: The captured log entries.
+    :ivar List[structlog.typing.EventDict] entries: The captured log entries.
 
     .. versionadded:: 20.1.0
     """
@@ -84,9 +92,9 @@ class ReturnLogger:
     Return the arguments that it's called with.
 
     >>> from structlog import ReturnLogger
-    >>> ReturnLogger().msg("hello")
+    >>> ReturnLogger().info("hello")
     'hello'
-    >>> ReturnLogger().msg("hello", when="again")
+    >>> ReturnLogger().info("hello", when="again")
     (('hello',), {'when': 'again'})
 
     .. versionchanged:: 0.3.0
@@ -100,8 +108,8 @@ class ReturnLogger:
         # Slightly convoluted for backwards compatibility.
         if len(args) == 1 and not kw:
             return args[0]
-        else:
-            return args, kw
+
+        return args, kw
 
     log = debug = info = warn = warning = msg
     fatal = failure = err = error = critical = exception = msg
